@@ -18,13 +18,16 @@ public:
     ~MainWindow();
 
 private:
+    Ui::MainWindow *ui;
+    QList<PlayerSheet*> *list;
     virtual void mousePressEvent(QMouseEvent *);
-    virtual void keyPressEvent(QKeyEvent *);
+    virtual bool event(QEvent *event);
 
     QLabel *coinLabel;
+    void deleteCoin();
 
 signals:
-    void StartTimerSignal();
+    void StartTimerSignal(int);
 
 public slots:
     void AddPlayer();
@@ -34,10 +37,6 @@ public slots:
 
 private slots:
     void FlipCoin();
-
-private:
-    Ui::MainWindow *ui;
-    QList<PlayerSheet*> *list;
 };
 
 #endif // MAINWINDOW_H
