@@ -17,7 +17,7 @@ private:
 
 private slots:
     void TimerTick();
-    void StartTimer();
+    void StartTimer(int);
     void textChanged(QString);
 
 };
